@@ -4,7 +4,7 @@
  * SPDX-License-Identifier: LGPL-2.1+
  */
 
-#define G_LOG_DOMAIN				"XbMachine"
+#define G_LOG_DOMAIN "XbMachine"
 
 #include "config.h"
 
@@ -23,7 +23,7 @@
  * Since: 0.1.1
  **/
 const gchar *
-xb_opcode_kind_to_string (XbOpcodeKind kind)
+xb_opcode_kind_to_string(XbOpcodeKind kind)
 {
 	/* special cases */
 	if (kind == XB_OPCODE_KIND_INTEGER)
@@ -58,41 +58,40 @@ xb_opcode_kind_to_string (XbOpcodeKind kind)
  * Since: 0.1.1
  **/
 XbOpcodeKind
-xb_opcode_kind_from_string (const gchar *str)
+xb_opcode_kind_from_string(const gchar *str)
 {
-	if (g_strcmp0 (str, "FUNC") == 0)
+	if (g_strcmp0(str, "FUNC") == 0)
 		return XB_OPCODE_KIND_FUNCTION;
-	if (g_strcmp0 (str, "TEXT") == 0)
+	if (g_strcmp0(str, "TEXT") == 0)
 		return XB_OPCODE_KIND_TEXT;
-	if (g_strcmp0 (str, "INTE") == 0)
+	if (g_strcmp0(str, "INTE") == 0)
 		return XB_OPCODE_KIND_INTEGER;
-	if (g_strcmp0 (str, "BIND") == 0)
+	if (g_strcmp0(str, "BIND") == 0)
 		return XB_OPCODE_KIND_BOUND_INTEGER;
-	if (g_strcmp0 (str, "?TXT") == 0)
+	if (g_strcmp0(str, "?TXT") == 0)
 		return XB_OPCODE_KIND_BOUND_TEXT;
-	if (g_strcmp0 (str, "?INT") == 0)
+	if (g_strcmp0(str, "?INT") == 0)
 		return XB_OPCODE_KIND_BOUND_INTEGER;
-	if (g_strcmp0 (str, "TEXI") == 0)
+	if (g_strcmp0(str, "TEXI") == 0)
 		return XB_OPCODE_KIND_INDEXED_TEXT;
-	if (g_strcmp0 (str, "BOOL") == 0)
+	if (g_strcmp0(str, "BOOL") == 0)
 		return XB_OPCODE_KIND_BOOLEAN;
 	return XB_OPCODE_KIND_UNKNOWN;
 }
 
 /* private */
 gchar *
-xb_opcode_get_sig (XbOpcode *self)
+xb_opcode_get_sig(XbOpcode *self)
 {
-	GString *str = g_string_new (xb_opcode_kind_to_string (self->kind));
+	GString *str = g_string_new(xb_opcode_kind_to_string(self->kind));
 	if (self->kind == XB_OPCODE_KIND_FUNCTION) {
-		g_string_append_printf (str, ":%s",
-					self->ptr != NULL ? (gchar *) self->ptr : "???");
+		g_string_append_printf(str, ":%s", self->ptr != NULL ? (gchar *)self->ptr : "???");
 	}
-	return g_string_free (str, FALSE);
+	return g_string_free(str, FALSE);
 }
 
 static const gchar *
-xb_opcode_get_str_for_display (XbOpcode *self)
+xb_opcode_get_str_for_display(XbOpcode *self)
 {
 	if (self->ptr == NULL)
 		return "(null)";
@@ -100,28 +99,26 @@ xb_opcode_get_str_for_display (XbOpcode *self)
 }
 
 static gchar *
-xb_opcode_to_string_internal (XbOpcode *self)
+xb_opcode_to_string_internal(XbOpcode *self)
 {
 	/* special cases */
 	if (self->kind == XB_OPCODE_KIND_INDEXED_TEXT)
-		return g_strdup_printf ("$'%s'", xb_opcode_get_str_for_display (self));
+		return g_strdup_printf("$'%s'", xb_opcode_get_str_for_display(self));
 	if (self->kind == XB_OPCODE_KIND_INTEGER)
-		return g_strdup_printf ("%u", xb_opcode_get_val (self));
-	if (self->kind == XB_OPCODE_KIND_BOUND_INTEGER)
-		return g_strdup ("?");
+		return g_strdup_printf("%u", xb_opcode_get_val(self));
 	if (self->kind == XB_OPCODE_KIND_BOUND_TEXT)
-		return g_strdup_printf ("?'%s'", xb_opcode_get_str_for_display (self));
+		return g_strdup_printf("?'%s'", xb_opcode_get_str_for_display(self));
 	if (self->kind == XB_OPCODE_KIND_BOUND_INTEGER)
-		return g_strdup_printf ("?%u", xb_opcode_get_val (self));
+		return g_strdup_printf("?%u", xb_opcode_get_val(self));
 	if (self->kind == XB_OPCODE_KIND_BOOLEAN)
-		return g_strdup (xb_opcode_get_val (self) ? "True" : "False");
+		return g_strdup(xb_opcode_get_val(self) ? "True" : "False");
 
 	/* bitwise fallbacks */
 	if (self->kind & XB_OPCODE_FLAG_FUNCTION)
-		return g_strdup_printf ("%s()", xb_opcode_get_str_for_display (self));
+		return g_strdup_printf("%s()", xb_opcode_get_str_for_display(self));
 	if (self->kind & XB_OPCODE_FLAG_TEXT)
-		return g_strdup_printf ("'%s'", xb_opcode_get_str_for_display (self));
-	g_critical ("no to_string for kind 0x%x", self->kind);
+		return g_strdup_printf("'%s'", xb_opcode_get_str_for_display(self));
+	g_critical("no to_string for kind 0x%x", self->kind);
 	return NULL;
 }
 
@@ -136,17 +133,17 @@ xb_opcode_to_string_internal (XbOpcode *self)
  * Since: 0.1.4
  **/
 gchar *
-xb_opcode_to_string (XbOpcode *self)
+xb_opcode_to_string(XbOpcode *self)
 {
-	g_autofree gchar *tmp = xb_opcode_to_string_internal (self);
+	g_autofree gchar *tmp = xb_opcode_to_string_internal(self);
 	if (self->kind & XB_OPCODE_FLAG_TOKENIZED) {
 		g_autofree gchar *tokens = NULL;
 		/* Ensure the array is NULL-terminated */
 		self->tokens[self->tokens_len] = NULL;
-		tokens = g_strjoinv (",", (gchar **) self->tokens);
-		return g_strdup_printf ("%s[%s]", tmp, tokens);
+		tokens = g_strjoinv(",", (gchar **)self->tokens);
+		return g_strdup_printf("%s[%s]", tmp, tokens);
 	}
-	return g_steal_pointer (&tmp);
+	return g_steal_pointer(&tmp);
 }
 
 /**
@@ -160,7 +157,7 @@ xb_opcode_to_string (XbOpcode *self)
  * Since: 0.1.1
  **/
 XbOpcodeKind
-xb_opcode_get_kind (XbOpcode *self)
+xb_opcode_get_kind(XbOpcode *self)
 {
 	return self->kind & ~XB_OPCODE_FLAG_TOKENIZED;
 }
@@ -177,7 +174,7 @@ xb_opcode_get_kind (XbOpcode *self)
  * Since: 0.3.1
  **/
 gboolean
-xb_opcode_has_flag (XbOpcode *self, XbOpcodeFlags flag)
+xb_opcode_has_flag(XbOpcode *self, XbOpcodeFlags flag)
 {
 	return (self->kind & flag) > 0;
 }
@@ -192,7 +189,7 @@ xb_opcode_has_flag (XbOpcode *self, XbOpcodeFlags flag)
  * Since: 0.3.1
  **/
 void
-xb_opcode_add_flag (XbOpcode *self, XbOpcodeFlags flag)
+xb_opcode_add_flag(XbOpcode *self, XbOpcodeFlags flag)
 {
 	self->kind |= flag;
 }
@@ -208,11 +205,10 @@ xb_opcode_add_flag (XbOpcode *self, XbOpcodeFlags flag)
  * Since: 0.1.1
  **/
 inline gboolean
-xb_opcode_cmp_val (XbOpcode *self)
+xb_opcode_cmp_val(XbOpcode *self)
 {
-	return self->kind == XB_OPCODE_KIND_INTEGER ||
-		self->kind == XB_OPCODE_KIND_BOOLEAN ||
-		self->kind == XB_OPCODE_KIND_BOUND_INTEGER;
+	return self->kind == XB_OPCODE_KIND_INTEGER || self->kind == XB_OPCODE_KIND_BOOLEAN ||
+	       self->kind == XB_OPCODE_KIND_BOUND_INTEGER;
 }
 
 /**
@@ -226,16 +222,16 @@ xb_opcode_cmp_val (XbOpcode *self)
  * Since: 0.1.1
  **/
 inline gboolean
-xb_opcode_cmp_str (XbOpcode *self)
+xb_opcode_cmp_str(XbOpcode *self)
 {
-	return xb_opcode_has_flag (self, XB_OPCODE_FLAG_TEXT);
+	return xb_opcode_has_flag(self, XB_OPCODE_FLAG_TEXT);
 }
 
 /* private */
 gboolean
-xb_opcode_is_binding (XbOpcode *self)
+xb_opcode_is_binding(XbOpcode *self)
 {
-	return xb_opcode_has_flag (self, XB_OPCODE_FLAG_BOUND);
+	return xb_opcode_has_flag(self, XB_OPCODE_FLAG_BOUND);
 }
 
 /**
@@ -250,7 +246,7 @@ xb_opcode_is_binding (XbOpcode *self)
  * Since: 0.1.1
  **/
 guint32
-xb_opcode_get_val (XbOpcode *self)
+xb_opcode_get_val(XbOpcode *self)
 {
 	return self->val;
 }
@@ -266,7 +262,7 @@ xb_opcode_get_val (XbOpcode *self)
  * Since: 0.1.1
  **/
 const gchar *
-xb_opcode_get_str (XbOpcode *self)
+xb_opcode_get_str(XbOpcode *self)
 {
 	return self->ptr;
 }
@@ -282,7 +278,7 @@ xb_opcode_get_str (XbOpcode *self)
  * Since: 0.3.1
  **/
 const gchar **
-xb_opcode_get_tokens (XbOpcode *self)
+xb_opcode_get_tokens(XbOpcode *self)
 {
 	return self->tokens;
 }
@@ -297,10 +293,10 @@ xb_opcode_get_tokens (XbOpcode *self)
  * Since: 0.2.0
  */
 void
-xb_opcode_clear (XbOpcode *self)
+xb_opcode_clear(XbOpcode *self)
 {
 	if (self->destroy_func)
-		self->destroy_func (self->ptr);
+		self->destroy_func(self->ptr);
 	self->destroy_func = NULL;
 }
 
@@ -316,9 +312,9 @@ xb_opcode_clear (XbOpcode *self)
  * Since: 0.2.0
  **/
 void
-xb_opcode_text_init (XbOpcode *opcode, const gchar *str)
+xb_opcode_text_init(XbOpcode *opcode, const gchar *str)
 {
-	xb_opcode_init (opcode, XB_OPCODE_KIND_TEXT, g_strdup (str), 0, g_free);
+	xb_opcode_init(opcode, XB_OPCODE_KIND_TEXT, g_strdup(str), 0, g_free);
 }
 
 /**
@@ -334,14 +330,14 @@ xb_opcode_text_init (XbOpcode *opcode, const gchar *str)
  * Since: 0.2.0
  **/
 void
-xb_opcode_init (XbOpcode       *opcode,
-                XbOpcodeKind    kind,
-                const gchar    *str,
-                guint32         val,
-                GDestroyNotify  destroy_func)
+xb_opcode_init(XbOpcode *opcode,
+	       XbOpcodeKind kind,
+	       const gchar *str,
+	       guint32 val,
+	       GDestroyNotify destroy_func)
 {
 	opcode->kind = kind;
-	opcode->ptr = (gpointer) str;
+	opcode->ptr = (gpointer)str;
 	opcode->val = val;
 	opcode->tokens_len = 0;
 	opcode->destroy_func = destroy_func;
@@ -358,9 +354,9 @@ xb_opcode_init (XbOpcode       *opcode,
  * Since: 0.2.0
  **/
 void
-xb_opcode_text_init_static (XbOpcode *opcode, const gchar *str)
+xb_opcode_text_init_static(XbOpcode *opcode, const gchar *str)
 {
-	xb_opcode_init (opcode, XB_OPCODE_KIND_TEXT, str, 0, NULL);
+	xb_opcode_init(opcode, XB_OPCODE_KIND_TEXT, str, 0, NULL);
 }
 
 /**
@@ -374,9 +370,9 @@ xb_opcode_text_init_static (XbOpcode *opcode, const gchar *str)
  * Since: 0.2.0
  **/
 void
-xb_opcode_text_init_steal (XbOpcode *opcode, gchar *str)
+xb_opcode_text_init_steal(XbOpcode *opcode, gchar *str)
 {
-	xb_opcode_init (opcode, XB_OPCODE_KIND_TEXT, g_steal_pointer (&str), 0, g_free);
+	xb_opcode_init(opcode, XB_OPCODE_KIND_TEXT, g_steal_pointer(&str), 0, g_free);
 }
 
 /**
@@ -391,9 +387,9 @@ xb_opcode_text_init_steal (XbOpcode *opcode, gchar *str)
  * Since: 0.2.0
  **/
 void
-xb_opcode_func_init (XbOpcode *opcode, guint32 func)
+xb_opcode_func_init(XbOpcode *opcode, guint32 func)
 {
-	xb_opcode_init (opcode, XB_OPCODE_KIND_FUNCTION, NULL, func, NULL);
+	xb_opcode_init(opcode, XB_OPCODE_KIND_FUNCTION, NULL, func, NULL);
 }
 
 /**
@@ -407,30 +403,30 @@ xb_opcode_func_init (XbOpcode *opcode, guint32 func)
  * Since: 0.2.0
  **/
 void
-xb_opcode_bind_init (XbOpcode *opcode)
+xb_opcode_bind_init(XbOpcode *opcode)
 {
-	xb_opcode_init (opcode, XB_OPCODE_KIND_BOUND_INTEGER, NULL, 0, NULL);
+	xb_opcode_init(opcode, XB_OPCODE_KIND_BOUND_INTEGER, NULL, 0, NULL);
 }
 
 /* private */
 void
-xb_opcode_bind_str (XbOpcode *self, gchar *str, GDestroyNotify destroy_func)
+xb_opcode_bind_str(XbOpcode *self, gchar *str, GDestroyNotify destroy_func)
 {
 	if (self->destroy_func) {
-		self->destroy_func (self->ptr);
+		self->destroy_func(self->ptr);
 		self->destroy_func = NULL;
 	}
 	self->kind = XB_OPCODE_KIND_BOUND_TEXT;
-	self->ptr = (gpointer) str;
-	self->destroy_func = (gpointer) destroy_func;
+	self->ptr = (gpointer)str;
+	self->destroy_func = (gpointer)destroy_func;
 }
 
 /* private */
 void
-xb_opcode_bind_val (XbOpcode *self, guint32 val)
+xb_opcode_bind_val(XbOpcode *self, guint32 val)
 {
 	if (self->destroy_func) {
-		self->destroy_func (self->ptr);
+		self->destroy_func(self->ptr);
 		self->destroy_func = NULL;
 	}
 	self->kind = XB_OPCODE_KIND_BOUND_INTEGER;
@@ -439,17 +435,17 @@ xb_opcode_bind_val (XbOpcode *self, guint32 val)
 
 /* private */
 void
-xb_opcode_set_val (XbOpcode *self, guint32 val)
+xb_opcode_set_val(XbOpcode *self, guint32 val)
 {
 	self->val = val;
 }
 
 /* private */
 gboolean
-xb_opcode_append_token (XbOpcode *self, const gchar *val)
+xb_opcode_append_token(XbOpcode *self, const gchar *val)
 {
-	g_return_val_if_fail (val != NULL, FALSE);
-	g_return_val_if_fail (val[0] != '\0', FALSE);
+	g_return_val_if_fail(val != NULL, FALSE);
+	g_return_val_if_fail(val[0] != '\0', FALSE);
 	if (self->tokens_len >= XB_OPCODE_TOKEN_MAX)
 		return FALSE;
 	self->tokens[self->tokens_len++] = val;
@@ -459,7 +455,7 @@ xb_opcode_append_token (XbOpcode *self, const gchar *val)
 
 /* private */
 void
-xb_opcode_set_kind (XbOpcode *self, XbOpcodeKind kind)
+xb_opcode_set_kind(XbOpcode *self, XbOpcodeKind kind)
 {
 	self->kind = kind;
 }
@@ -474,14 +470,14 @@ xb_opcode_set_kind (XbOpcode *self, XbOpcodeKind kind)
  * Since: 0.2.0
  **/
 void
-xb_opcode_integer_init (XbOpcode *opcode, guint32 val)
+xb_opcode_integer_init(XbOpcode *opcode, guint32 val)
 {
-	xb_opcode_init (opcode, XB_OPCODE_KIND_INTEGER, NULL, val, NULL);
+	xb_opcode_init(opcode, XB_OPCODE_KIND_INTEGER, NULL, val, NULL);
 }
 
 /* private */
 void
-xb_opcode_bool_init (XbOpcode *opcode, gboolean val)
+xb_opcode_bool_init(XbOpcode *opcode, gboolean val)
 {
-	xb_opcode_init (opcode, XB_OPCODE_KIND_BOOLEAN, NULL, !!val, NULL);
+	xb_opcode_init(opcode, XB_OPCODE_KIND_BOOLEAN, NULL, !!val, NULL);
 }
