@@ -728,6 +728,64 @@ xb_builder_node_vfunc_error_func(void)
 	g_assert_null(silo);
 }
 
+static gboolean
+xb_builder_ignore_cb(XbBuilderFixup *self, XbBuilderNode *bn, gpointer user_data, GError **error)
+{
+	if (xb_builder_node_get_element(bn) != NULL)
+		xb_builder_node_add_flag(bn, XB_BUILDER_NODE_FLAG_IGNORE);
+	return TRUE;
+}
+
+static void
+xb_builder_node_vfunc_ignore_func(void)
+{
+	XbNodeChildIter iter;
+	gboolean ret;
+	const gchar *element;
+	g_autoptr(GError) error = NULL;
+	g_autoptr(XbBuilder) builder = xb_builder_new();
+	g_autoptr(XbBuilderFixup) fixup = NULL;
+	g_autoptr(XbBuilderSource) source = xb_builder_source_new();
+	g_autoptr(XbBuilderNode) info = NULL;
+	g_autoptr(XbSilo) silo = NULL;
+	g_autoptr(XbNode) n = NULL;
+	g_autoptr(XbNode) c = NULL;
+	g_autoptr(XbNode) c2 = NULL;
+
+	/* add fixup */
+	fixup = xb_builder_fixup_new("AlwaysIgnore", xb_builder_ignore_cb, NULL, NULL);
+	xb_builder_source_add_fixup(source, fixup);
+
+	/* import some XML with metadata */
+	ret = xb_builder_source_load_xml(source,
+					 "<component><id>gimp.desktop</id></component>",
+					 XB_BUILDER_SOURCE_FLAG_NONE,
+					 &error);
+	g_assert_no_error(error);
+	g_assert_true(ret);
+	info = xb_builder_node_insert(NULL, "info", NULL);
+	xb_builder_node_insert_text(info, "foo", "bar", NULL);
+	xb_builder_source_set_info(source, info);
+	xb_builder_import_source(builder, source);
+
+	/* compile */
+	silo = xb_builder_compile(builder, XB_BUILDER_COMPILE_FLAG_NONE, NULL, &error);
+	g_assert_no_error(error);
+	g_assert_nonnull(silo);
+	n = xb_silo_get_root(silo);
+	g_assert_nonnull(n);
+	element = xb_node_get_element(n);
+	g_assert_null(element);
+	c = xb_node_get_child(n);
+	g_assert_null(c);
+	c = xb_node_get_next(n);
+	g_assert_null(c);
+	xb_node_child_iter_init(&iter, n);
+	ret = xb_node_child_iter_next(&iter, &c2);
+	g_assert_false(ret);
+	g_assert_null(c2);
+}
+
 static gboolean
 xb_builder_upgrade_appstream_cb(XbBuilderFixup *self,
 				XbBuilderNode *bn,
@@ -2681,6 +2739,7 @@ main(int argc, char **argv)
 	g_test_add_func("/libxmlb/builder{node-vfunc-remove}", xb_builder_node_vfunc_remove_func);
 	g_test_add_func("/libxmlb/builder{node-vfunc-depth}", xb_builder_node_vfunc_depth_func);
 	g_test_add_func("/libxmlb/builder{node-vfunc-error}", xb_builder_node_vfunc_error_func);
+	g_test_add_func("/libxmlb/builder{node-vfunc-ignore}", xb_builder_node_vfunc_ignore_func);
 	g_test_add_func("/libxmlb/builder{ignore-invalid}", xb_builder_ignore_invalid_func);
 	g_test_add_func("/libxmlb/builder{custom-mime}", xb_builder_custom_mime_func);
 	g_test_add_func("/libxmlb/builder{chained-adapters}", xb_builder_chained_adapters_func);
@@ -2705,9 +2764,9 @@ main(int argc, char **argv)
 	g_test_add_func("/libxmlb/xpath-parent-subnode", xb_xpath_parent_subnode_func);
 	g_test_add_func("/libxmlb/multiple-roots", xb_builder_multiple_roots_func);
 	g_test_add_func("/libxmlb/single-root", xb_builder_single_root_func);
-	if (g_test_perf())
+	if (g_test_perf()) {
 		g_test_add_func("/libxmlb/threading", xb_threading_func);
-	if (g_test_perf())
 		g_test_add_func("/libxmlb/speed", xb_speed_func);
+	}
 	return g_test_run();
 }
